@@ -1327,7 +1327,7 @@ def computefilteredimage(dataimage, bkg_image, CCDlabel, kernelsize=5, formulaex
     #     if framedim not in ((2048, 2048), [2048, 2048]):
     #         raise ValueError, "Background removal still implemented for non squared camera "
     # computing substraction on whole array
-    if CCDlabel in ("sCMOS", "sCMOS_fliplr"):
+    if CCDlabel in ("sCMOS", "sCMOS_fliplr", "sCMOS_16M"):
         usemask = False
 
     if usemask:
